@@ -1,6 +1,8 @@
 /* gzip.h -- common declarations for all gzip modules
 
-   Copyright (C) 1997, 1998, 1999, 2001, 2006 Free Software Foundation, Inc.
+   Copyright (C) 1997, 1998, 1999, 2001, 2006, 2007 Free Software
+   Foundation, Inc.
+
    Copyright (C) 1992-1993 Jean-loup Gailly.
 
    This program is free software; you can redistribute it and/or modify
@@ -43,7 +45,8 @@
  * too often
  */
 #include <stdio.h>
-#include <sys/types.h> /* for off_t, time_t */
+#include <sys/types.h> /* for off_t */
+#include <time.h>
 #if defined HAVE_STRING_H || defined STDC_HEADERS
 #  include <string.h>
 #  if !defined STDC_HEADERS && defined HAVE_MEMORY_H && !defined __GNUC__
@@ -59,10 +62,6 @@
 #  define memzero(s, n)     bzero((s), (n))
 #endif
 
-#ifdef HAVE_LIMITS_H
-# include <limits.h>
-#endif
-
 #ifndef RETSIGTYPE
 #  define RETSIGTYPE void
 #endif
@@ -105,10 +104,6 @@ extern int method;         /* compression method */
 #  else
 #    define INBUFSIZ  0x8000  /* input buffer size */
 #  endif
-#  if defined SSIZE_MAX && SSIZE_MAX < INBUFSIZ
-#    undef INBUFSIZ
-#    define INBUFSIZ SSIZE_MAX
-#  endif
 #endif
 #define INBUF_EXTRA  64     /* required by unlzw() */
 
@@ -329,6 +324,7 @@ extern int  fill_inbuf    OF((int eof_ok));
 extern void flush_outbuf  OF((void));
 extern void flush_window  OF((void));
 extern void write_buf     OF((int fd, voidp buf, unsigned cnt));
+extern int read_buffer    OF((int fd, voidp buf, unsigned int cnt));
 extern char *strlwr       OF((char *s));
 extern char *gzip_base_name OF((char *fname));
 extern int xunlink        OF((char *fname));
