@@ -8,7 +8,7 @@
  */
 
 #ifdef RCSID
-static char rcsid[] = "$Id: unlzw.c,v 1.4 2006/11/20 08:40:34 eggert Exp $";
+static char rcsid[] = "$Id: unlzw.c,v 1.5 2006/12/11 18:54:39 eggert Exp $";
 #endif
 
 #include <config.h>
@@ -257,7 +257,8 @@ int unlzw(in, out)
 	posbits = 0;
 
 	if (insize < INBUF_EXTRA) {
-	    if ((rsize = read(in, (char*)inbuf+insize, INBUFSIZ)) == -1) {
+	    rsize = read_buffer (in, (char *) inbuf + insize, INBUFSIZ);
+	    if (rsize == -1) {
 		read_error();
 	    }
 	    insize += rsize;
